@@ -9,8 +9,9 @@ int xtoolkit_init (int *argc, char *argv []);
 void xtoolkit_end (void);
 
 extern Dlg_head *desktop_dlg;
-extern int nowindows;
+extern int nowindows, nodesktop, twopanel;
 extern int corba_have_server;
+extern int use_magic;
 
 /* Required by the standard code */
 widget_data xtoolkit_create_dialog   (Dlg_head *h, int with_grid);
